# -*- coding: utf-8 -*-
"""
Correction de l'exercie de préparation de données
.
"""
import re
import csv
import os

def departement_by_cu(rep, cdescr=0):
    """
    Fonction pour obtenir la liste des CU par département

    Arguments:
      * book   -- le workbook à lire
      * cdescr -- la colonne contenant la description à rechercher
    renvoie: un générateur sur la liste des CU par département
    """
    fichiers = os.listdir(rep)
    
    res = {}
    for dept in fichiers:
        nomdept = re.sub(r".csv$", "", dept)
        file = open(rep+"/"+dept, "r")
        reader = csv.reader(file, delimiter=',', quotechar='"')
        for line in reader:
            val = line[cdescr]
            if (val == None):
                ## Si la case est vide ça fait planter le regex.search
                continue
            m = re.match(r"^(Métropole|CU|CA) (de |du |d')*(.*)$", val)
            if (m):
                res[val] = nomdept
    return res
    

def generator_cu_csv(nomfich, dept_by_cu, cdescr = 0, cols = [1,2,3]):
    """
    Fonction qui génère un itérable sur les communauté urbaine, c. d'aglomération
    et Métropol de la région.
    
    Arguments:
      * nomfile   -- le nom du fichier à analyser
      * dpt_by_cu -- un dictionnaire contenant les département par communauté urbaine
      * cdescr    -- la colonne contenant la description à rechercher
      * cols      -- colonnes à concerver.
    """
    cvsfile = open(nomfich, 'r')
    reader = csv.reader(cvsfile,  delimiter=',', quotechar='"')
    res = []
    trouve = False
    for line in reader:
#        line = [cell.encode('utf-8') for cell in line]
        ## On parcours les lignes
        val = line[cdescr]
#        print("lu '{}'".format(val))
        if (val == None):
            ## Si la case est vide ça fait planter le regex.search
            continue
        if not(trouve):
            ## On essaye de rechercher les lignes qui commencent par métrolpole ou CU ou CA.
            ## si c'est le cas, on lit la ville la prochaine fois et on renvoie le résultat
            m = re.match(r"^(Métropole|CU|CA) (de |du |d')*(.*)$", val)
            if (m):
                res.append(m.group(3))
                res.append(dept_by_cu[val])
                res.append(m.group(1))
                trouve = True
            if trouve:
                ## on ajoute les autres colonnes intéréssantes
                for c in cols:
                    res.append(line[c])
        else:
            ## On a trouvé une CU à la ligne précédente? Cette ligne contient la ville
            trouve = False
            m = re.match(r"^dont (.*)$", val)
            if (m):
                res.insert(1,m.group(1))
            else:
                res.insert(1,None)
            #            print("trouvé !!! '{}'".format(res))
            yield(res)
            res = []
            

fich_region = "Population/Region.csv"
DbyCU = departement_by_cu("Population/Dept/")


list_CU = generator_cu_csv(fich_region, DbyCU)

fres = open("result.csv", "w")
writer = csv.writer(fres, delimiter=',',
                    quotechar='"', quoting=csv.QUOTE_MINIMAL)
writer.writerow(["Nom", "Ville", "Département", "Type", "1999", "2009", "2014"])
for dat in list_CU:
    print("Trouvé : {}".format(dat))
    writer.writerow(dat)
fres.close()
    
    
# >>> print(sheet_ranges['D18'].value)