# -*- coding: utf-8 -*-
"""
Correction de l'exercie de préparation de données
.
"""
from openpyxl import load_workbook
import re


def departement_by_cu(book, cdescr=0):
    """
    Fonction pour obtenir la liste des CU par département

    Arguments:
      * book   -- le workbook à lire
      * cdescr -- la colonne contenant la description à rechercher
    renvoie: un générateur sur la liste des CU par département
    """
    sheets = book.sheetnames
    sheets = sheets[2:-1] ## on ignore les 2 première et la dernière
    res = {}
    for dept in sheets:
        for line in book[dept]:
            val = line[cdescr].value
            if (val == None):
                ## Si la case est vide ça fait planter le regex.search
                continue
            m = re.match(r"^(Métropole|CU|CA) (de |du |d')*(.*)$", val)
            if (m):
                res[val] = dept
    return res
    

def generator_cu_from_sheet(sheet, dept_by_cu, cdescr = 0, cols = [1,2,3]):
    """
    Fonction qui génère un itérable sur les communauté urbaine, c. d'aglomération
    et Métropol de la région.
    
    Arguments:
      * sheet     -- la feuille à analyser
      * dpt_by_cu -- un dictionnaire contenant les département par communauté urbaine
      * cdescr    -- la colonne contenant la description à rechercher
      * cols      -- colonnes à concerver.
    """
    res = []
    trouve = False
    for line in sheet_region.rows:
        ## On parcours les lignes
        val = line[cdescr].value
        # print("lu '{}'".format(val))
        if (val == None):
            ## Si la case est vide ça fait planter le regex.search
            continue
        if not(trouve):
            ## On essaye de rechercher les lignes qui commencent par métrolpole ou CU ou CA.
            ## si c'est le cas, on lit la ville la prochaine fois et on renvoie le résultat
            m = re.match(r"^(Métropole|CU|CA) (de |du |d')*(.*)$", val)
            if (m):
                res.append(m.group(3))
                res.append(dept_by_cu[val])
                res.append(m.group(1))
                trouve = True
            if trouve:
                ## on ajoute les autres colonnes intéréssantes
                for c in cols:
                    res.append(line[c].value)
        else:
            ## On a trouvé une CU à la ligne précédente? Cette ligne contient la ville
            trouve = False
            m = re.match(r"^dont (.*)$", val)
            if (m):
                res.insert(1,m.group(1))
            else:
                res.insert(1,None)
            #            print("trouvé !!! '{}'".format(res))
            yield(res)
            res = []
            

wb = load_workbook(filename = 'ar_cd_pop_2009_2014.xlsx')
sheet_region = wb['AUVERGNE-RHÔNE-ALPES']

DbyCU = departement_by_cu(wb)

print(DbyCU)

list_CU = generator_cu_from_sheet(sheet_region, DbyCU)

for dat in list_CU:
    print("Trouvé : {}".format(dat))


    
    
# >>> print(sheet_ranges['D18'].value)